@@ -2,8 +2,10 @@ pub mod close;
 pub mod extend_expiration;
 pub mod init;
 pub mod invalidate;
+pub mod reset_expiration;
 
 pub use close::*;
 pub use extend_expiration::*;
 pub use init::*;
 pub use invalidate::*;
+pub use reset_expiration::*;
